import { Provider } from "jotai";
import { ThemeProvider } from "@/providers/theme-provider";

import type { Metadata } from "next";
import { Barlow, Bokor } from "next/font/google";
import NextTopLoader from "nextjs-toploader";
import { Toaster } from "sonner";
import "./globals.css";
import { AuthProvider } from "@/providers/AuthProvider";
import QueryProvider from "@/providers/query-provider";
import { getServerSession } from "next-auth";
import { authOptions } from "./auth";
const barlow = Barlow({
  subsets: ["latin"],
  weight: ["100", "300", "400", "500", "600", "700", "800", "900"],
  variable: "--font-barlow",
});

const bokor = Bokor({
  subsets: ["latin"],
  weight: ["400"],
  variable: "--font-bokor",
});

export const metadata: Metadata = {
  title: "SAR Link Portal",
  description: "Sarlink Portal",
};

export default async function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  const session = await getServerSession(authOptions);
  return (
    <html lang="en" suppressHydrationWarning>
      <body className={`${barlow.variable} ${bokor.variable} antialiased font-sans bg-gray-100 dark:bg-black`}>
        <AuthProvider session={session || undefined}>
          <Provider>
            <NextTopLoader color="#f49d1b" showSpinner={false} zIndex={9999} />
            <Toaster richColors />
            <ThemeProvider
              attribute="class"
              defaultTheme="system"
              enableSystem
              disableTransitionOnChange
            >
              <QueryProvider>
                {children}
              </QueryProvider>
            </ThemeProvider>
          </Provider>
        </AuthProvider>
      </body>

    </html>
  );
}
